import static org.lwjgl.glfw.GLFW.*;
import static org.lwjgl.opengl.GL11.*;
import org.lwjgl.opengl.GL;

public class Program
{
    public Program()
    {
        if (!glfwInit())
        {
            System.err.println("GLFW failed to initialize.");
            System.exit(1);
        }

        int width = 256;
        int height = 256;
        long win = glfwCreateWindow(width, height, "Circle", 0, 0);
        glfwShowWindow(win);

        glfwMakeContextCurrent(win);
        GL.createCapabilities();

        float radius = 0.8f;
        int amountOfVertices = 30;
        float[] vertices;

        vertices = CreateCircle(radius, amountOfVertices);

        int[] indices = new int[amountOfVertices * 2];
        indices[0] = indices[indices.length - 1] = 0;
        int index = 1;
        for (int i = 1; i <= indices.length - 2; i += 2)
        {
            indices[i] = index;
            indices[i + 1] = index;
            index++;
        }

        Model model = new Model(vertices, indices);
        Shader shader = new Shader("shader");

        while (!glfwWindowShouldClose(win))
        {
            glfwPollEvents();

            if (glfwGetKey(win, GLFW_KEY_ESCAPE) == GLFW_PRESS)
            {
                glfwSetWindowShouldClose(win, true);
            }

            glClear(GL_COLOR_BUFFER_BIT);

            shader.Bind();
            model.Render();

            glfwSwapBuffers(win);
        }

        glfwTerminate();
    }

    private float[] CreateCircle(float radius, int amountOfVertices)
    {
        float[] vertices = new float[amountOfVertices * 2];

        vertices[0] = radius;
        vertices[1] = 0f;
        
        float angleStep = 360f / (float) amountOfVertices;
        float angle = angleStep;

        for (int i = 2; i < vertices.length; i += 2)
        {
            vertices[i] = radius * (float) Math.cos(angle * (float)Math.PI / 180f);
            vertices[i + 1] = radius * (float) Math.sin(angle * (float)Math.PI / 180f);
            angle += angleStep;
        }

        return vertices;
    }

    public static void main(String[] args)
    {
        new Program();
    }
}
