import static org.lwjgl.opengl.GL20.*;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;

public class Shader
{
    private int _program;
    private int _vs;
    private int _fs;

    public Shader(String fileName)
    {
        _program = glCreateProgram();

        _vs = glCreateShader(GL_VERTEX_SHADER);
        glShaderSource(_vs, ReadFile(fileName + ".vs"));
        glCompileShader(_vs);
        if (glGetShaderi(_vs, GL_COMPILE_STATUS) != 1)
        {
            System.err.println(glGetShaderInfoLog(_vs));
            System.exit(1);
        }

        _fs = glCreateShader(GL_FRAGMENT_SHADER);
        glShaderSource(_fs, ReadFile(fileName + ".fs"));
        glCompileShader(_fs);
        if (glGetShaderi(_fs, GL_COMPILE_STATUS) != 1)
        {
            System.err.println(glGetShaderInfoLog(_fs));
            System.exit(1);
        }

        glAttachShader(_program, _vs);
        glAttachShader(_program, _fs);

        glBindAttribLocation(_program, 0, "aPosition");
        
        glLinkProgram(_program);
        if (glGetProgrami(_program, GL_LINK_STATUS) != 1)
        {
            System.err.println(glGetProgramInfoLog(_program));
            System.exit(1);
        }
        glValidateProgram(_program);
        if (glGetProgrami(_program, GL_VALIDATE_STATUS) != 1)
        {
            System.err.println(glGetProgramInfoLog(_program));
            System.exit(1);
        }
    }
    
    public void Bind()
    {
        glUseProgram(_program);
    }

    private String ReadFile(String fileName)
    {
        StringBuilder string = new StringBuilder();
        BufferedReader br;
        try
        {
            br = new BufferedReader(new FileReader(new File("./shaders/" + fileName)));
            String line;
            while ((line = br.readLine()) != null)
            {
                string.append(line);
                string.append("\n");
            }
            br.close();
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
        return string.toString();
    }
}
